# libtetrabz

Libtetrabz is a library which perform efficiently the Brillouin-zone 
integration in the electronic structure calculation in a solid by 
using the tetrahedron method.

## Quick start guide

To experience libtetrabz, please open the following python notebook with jupyter, Google colab, etc.

https://github.com/mitsuaki1987/libtetrabz/blob/main/python/src/libtetrabz_tutorial.ipynb

## Manual

https://mitsuaki1987.github.io/libtetrabz/python/_build/html/index.html

## For citing libtetrabz
We would appreciate if you cite the following article in your 
research with libtetrabz.

"Improved tetrahedron method for the Brillouin-zone integration applicable to response functions",

M. Kawamura, Y. Gohda, and S. Tsuneyuki, Phys. Rev. B 89, 094515 (2014).
arXiv:2203.15648

https://journals.aps.org/prb/abstract/10.1103/PhysRevB.89.094515
https://arxiv.org/abs/2203.15648

## Git repository

https://github.com/mitsuaki1987/libtetrabz
